@@ -4,4 +4,4 @@ from .configuration import config
 from .event import Event, on, emit
 from .loop import loop
 from .cli import command
-from .utils import require, uuid, tri_wave, float_range
+from .utils import require, uuid, tri_wave, float_range, retry
